==> cvam_0.9.0.tar.gz: cvam/src/icodes_2.h <==
"advance_cell_fixed_part                                                 ",&
"advance_cell_fixed_part_estimate                                        ",&
"advance_cell_random_part                                                ",&
"advance_cell_random_part_estimate                                       ",&
"advance_to_next_cell                                                    ",&
"advance_to_next_cell_2                                                  ",&
"cholesky_saxpy                                                          ",&
"compute_center_and_scale_beta_da                                        ",&
"compute_estimate_SEs                                                    ",&
"compute_estimates                                                       ",&
"compute_lambda_from_beta                                                ",&
"compute_lik_table                                                       ",&
"compute_lik_values                                                      ",&
"compute_logP_score_hessian_beta_da                                      ",&
"compute_log_proposal_beta                                               ",&
"compute_loglik_logprior                                                 ",&
"compute_ls_fit                                                          ",&
"compute_mu_from_beta                                                    ",&
"compute_predictions                                                     ",&
"compute_scale_rwm                                                       ",&
"compute_score_hessian_mstep                                             ",&
"compute_vhat_beta                                                       ",&
"create_data_and_prior_use_objects                                       ",&
"create_estimate_objects                                                 ",&
"create_lik_objects                                                      ",&
"create_mcmc_objects                                                     ",&
"create_model_fitting_objects                                            ",&
"create_predict_objects                                                  ",&
"dbeta_R                                                                 ",&
"dbinom_R                                                                ",&
"dbinom_raw_R                                                            ",&
"dbl1_alloc                                                              ",&
"dbl1_dealloc                                                            ",&
"dbl2_alloc                                                              ",&
"dbl2_dealloc                                                            ",&
"dbl3_alloc                                                              ",&
"dbl3dealloc                                                             ",&
"dbl4_alloc                                                              ",&
"dbl4dealloc                                                             ",&
"dchisq_R                                                                ",&
"dgamma_R                                                                ",&
"digamma_R                                                               ",&
"dnbinom_R                                                               ",&
"dnorm_R                                                                 ",&
"dpois_R                                                                 ",&
"dpois_raw_R                                                             ",&
"draw_approx_bayes_beta                                                  ",&
"draw_candidate_beta                                                     ",&
"draw_candidate_beta_rwm                                                 ",&
"dt_R                                                                    ",&
"dunif_R                                                                 ",&
"expm1_R                                                                 ",&
"fill_impute_result_mat                                                  ",&
"fill_input_data_with_missing                                            ",&
"flatten_table                                                           ",&
"flatten_table_with_derivs                                               ",&
"get_integer_table_values                                                ",&
"get_randgen_state_R                                                     ",&
"get_real_table_values                                                   ",&
"get_string_table_values                                                 ",&
"get_table_frequencies                                                   ",&
"get_table_length                                                        ",&
"get_table_type                                                          ",&
"house                                                                   ",&
"householder_ols                                                         ",&
"householder_qr                                                          ",&
"householder_qr2                                                         ",&
"householder_qr2_pivot                                                   ",&
"householder_qr_pivot                                                    ",&
"int1_alloc                                                              ",&
"int1_dealloc                                                            ",&
"int2_alloc                                                              ",&
"int2_dealloc                                                            ",&
"int3_alloc                                                              ",&
"int3_dealloc                                                            ",&
"invert_lower                                                            ",&
"kill_integer_tree                                                       ",&
"kill_real_tree                                                          ",&
"kill_string_tree                                                        ",&
"kronecker                                                               ",&
"kronecker_lower_tri                                                     ",&
"kronecker_symm                                                          ",&
"lgamma1p_R                                                              ",&
"lgamma_R                                                                ",&
"llincgamma                                                              ",&
"llincgamma_d1                                                           ",&
"llincgamma_d2                                                           ",&
"llincgamma_deriv_1                                                      ",&
"llincgamma_deriv_2                                                      ",&
"log1_alloc                                                              ",&
"log1_dealloc                                                            ",&
"log1p_R                                                                 ",&
"log1pexp_R                                                              ",&
"log1pmx_R                                                               ",&
"log2_alloc                                                              ",&
"log2_dealloc                                                            ",&
"log3_alloc                                                              ",&
"log3_dealloc                                                            ",&
"normalize_prob                                                          ",&
"nullify_table                                                           ",&
"nullify_workspace_type_cvam                                             ",&
"nullify_workspace_type_cvam_estimate                                    ",&
"nullify_workspace_type_cvam_predict                                     ",&
"nullify_workspace_type_int_array_1d                                     ",&
"nullify_workspace_type_int_array_2d                                     ",&
"nullify_workspace_type_int_array_3d                                     ",&
"pbeta_R                                                                 ",&
"pbinom_R                                                                ",&
"pchisq_R                                                                ",&
"pgamma_R                                                                ",&
"pnbinom_R                                                               ",&
"pnorm_R                                                                 ",&
"ppois_R                                                                 ",&
"premult_lower_by_transpose                                              ",&
"pt_R                                                                    ",&
"punif_R                                                                 ",&
"put_ctrl_into_workspace                                                 ",&
"put_data_into_workspace                                                 ",&
"put_method_into_workspace                                               ",&
"put_model_into_workspace                                                ",&
"put_model_type_into_workspace                                           ",&
"put_params_into_workspace                                               ",&
"put_prior_into_workspace                                                ",&
"put_randgen_state_R                                                     ",&
"qbeta_R                                                                 ",&
"qbinom_R                                                                ",&
"qchisq_R                                                                ",&
"qgamma_R                                                                ",&
"qnbinom_R                                                               ",&
"qnorm_R                                                                 ",&
"qpois_R                                                                 ",&
"qsort_double                                                            ",&
"qsort_integer                                                           ",&
"qsort_strings                                                           ",&
"qt_R                                                                    ",&
"qunif_R                                                                 ",&
"rbeta_R                                                                 ",&
"rbinom_R                                                                ",&
"rchisq_R                                                                ",&
"rgamma_R                                                                ",&
"rnbinom_R                                                               ",&
"rnorm_R                                                                 ",&
"row_house                                                               ",&
"row_house_vec                                                           ",&
"rpois_R                                                                 ",&
"rt_R                                                                    ",&
"run_approx_bayes_log_linear                                             ",&
"run_cvam_estimate_em                                                    ",&
"run_cvam_impute_freq                                                    ",&
"run_cvam_impute_microdata                                               ",&
"run_cvam_lik                                                            ",&
"run_cvam_model                                                          ",&
"run_cvam_predict_em                                                     ",&
"run_da_log_linear                                                       ",&
"run_da_saturated                                                        ",&
"run_em_log_linear                                                       ",&
"run_em_saturated                                                        ",&
"run_estep                                                               ",&
"run_estep_single_row                                                    ",&
"run_estep_single_row_with_derivs                                        ",&
"run_estep_with_derivs                                                   ",&
"run_istep                                                               ",&
"run_istep_microdata                                                     ",&
"run_mh_step_beta_da                                                     ",&
"run_mstep_log_linear                                                    ",&
"run_rwm_log_linear                                                      ",&
"run_rwm_step_beta                                                       ",&
"runif_R                                                                 ",&
"start_val_log_linear                                                    ",&
"start_val_saturated                                                     ",&
"str1_alloc                                                              ",&
"str1_dealloc                                                            ",&
"str2_alloc                                                              ",&
"str2_dealloc                                                            ",&
"str3_alloc                                                              ",&
"str3_dealloc                                                            ",&
"str_zero_check_single_row                                               ",&
"structural_zero_check                                                   ",&
"sweep_forward                                                           ",&
"sweep_reverse                                                           ",&
"tabulate_integer_number                                                 ",&
"tabulate_integer_variable                                               ",&
"tabulate_real_number                                                    ",&
"tabulate_real_variable                                                  ",&
"tabulate_string                                                         ",&
"tabulate_string_variable                                                ",&
"trigamma_R                                                              ",&
"update_freq_mean                                                        ",&
"update_running_means                                                    ",&
"write_integer_tree_to_table                                             ",&
"write_real_tree_to_table                                                ",&
"write_string_tree_to_table                                              ",&

==> cvam_0.9.1.tar.gz: cvam/src/icodes_2.h <==
"advance_cell_fixed_part                                                 ",&
"advance_cell_fixed_part_estimate                                        ",&
"advance_cell_random_part                                                ",&
"advance_cell_random_part_estimate                                       ",&
"advance_to_next_cell                                                    ",&
"advance_to_next_cell_2                                                  ",&
"check_lcprev_loglik_derivs_args                                         ",&
"check_mlogit_args                                                       ",&
"check_mlogit_loglik_derivs_args                                         ",&
"cholesky_saxpy                                                          ",&
"compute_center_and_scale_beta_da                                        ",&
"compute_estimate_SEs                                                    ",&
"compute_estimates                                                       ",&
"compute_lambda_from_beta                                                ",&
"compute_lik_table                                                       ",&
"compute_lik_values                                                      ",&
"compute_logP_score_hessian_beta_da                                      ",&
"compute_log_proposal_beta                                               ",&
"compute_loglik_logprior                                                 ",&
"compute_ls_fit                                                          ",&
"compute_mu_from_beta                                                    ",&
"compute_pi_mat                                                          ",&
"compute_predictions                                                     ",&
"compute_scale_rwm                                                       ",&
"compute_score_hess_lcprev                                               ",&
"compute_score_hess_mlogit                                               ",&
"compute_score_hessian_mstep                                             ",&
"compute_vhat_beta                                                       ",&
"create_data_and_prior_use_objects                                       ",&
"create_estimate_objects                                                 ",&
"create_lik_objects                                                      ",&
"create_mcmc_objects                                                     ",&
"create_model_fitting_objects                                            ",&
"create_nvec                                                             ",&
"create_predict_objects                                                  ",&
"dbeta_R                                                                 ",&
"dbinom_R                                                                ",&
"dbinom_raw_R                                                            ",&
"dbl1_alloc                                                              ",&
"dbl1_dealloc                                                            ",&
"dbl2_alloc                                                              ",&
"dbl2_dealloc                                                            ",&
"dbl3_alloc                                                              ",&
"dbl3dealloc                                                             ",&
"dbl4_alloc                                                              ",&
"dbl4dealloc                                                             ",&
"dchisq_R                                                                ",&
"dgamma_R                                                                ",&
"digamma_R                                                               ",&
"dnbinom_R                                                               ",&
"dnorm_R                                                                 ",&
"dpois_R                                                                 ",&
"dpois_raw_R                                                             ",&
"draw_approx_bayes_beta                                                  ",&
"draw_candidate_beta                                                     ",&
"draw_candidate_beta_rwm                                                 ",&
"dt_R                                                                    ",&
"dunif_R                                                                 ",&
"expm1_R                                                                 ",&
"fill_impute_result_mat                                                  ",&
"fill_input_data_with_missing                                            ",&
"flatten_table                                                           ",&
"flatten_table_with_derivs                                               ",&
"get_integer_table_values                                                ",&
"get_randgen_state_R                                                     ",&
"get_real_table_values                                                   ",&
"get_string_table_values                                                 ",&
"get_table_frequencies                                                   ",&
"get_table_length                                                        ",&
"get_table_type                                                          ",&
"house                                                                   ",&
"householder_ols                                                         ",&
"householder_qr                                                          ",&
"householder_qr2                                                         ",&
"householder_qr2_pivot                                                   ",&
"householder_qr_pivot                                                    ",&
"int1_alloc                                                              ",&
"int1_dealloc                                                            ",&
"int2_alloc                                                              ",&
"int2_dealloc                                                            ",&
"int3_alloc                                                              ",&
"int3_dealloc                                                            ",&
"invert_lower                                                            ",&
"kill_integer_tree                                                       ",&
"kill_real_tree                                                          ",&
"kill_string_tree                                                        ",&
"kronecker                                                               ",&
"kronecker_lower_tri                                                     ",&
"kronecker_symm                                                          ",&
"lgamma1p_R                                                              ",&
"lgamma_R                                                                ",&
"llincgamma                                                              ",&
"llincgamma_d1                                                           ",&
"llincgamma_d2                                                           ",&
"llincgamma_deriv_1                                                      ",&
"llincgamma_deriv_2                                                      ",&
"log1_alloc                                                              ",&
"log1_dealloc                                                            ",&
"log1p_R                                                                 ",&
"log1pexp_R                                                              ",&
"log1pmx_R                                                               ",&
"log2_alloc                                                              ",&
"log2_dealloc                                                            ",&
"log3_alloc                                                              ",&
"log3_dealloc                                                            ",&
"normalize_prob                                                          ",&
"nullify_table                                                           ",&
"nullify_workspace_type_cvam                                             ",&
"nullify_workspace_type_cvam_estimate                                    ",&
"nullify_workspace_type_cvam_predict                                     ",&
"nullify_workspace_type_int_array_1d                                     ",&
"nullify_workspace_type_int_array_2d                                     ",&
"nullify_workspace_type_int_array_3d                                     ",&
"pbeta_R                                                                 ",&
"pbinom_R                                                                ",&
"pchisq_R                                                                ",&
"pgamma_R                                                                ",&
"pnbinom_R                                                               ",&
"pnorm_R                                                                 ",&
"ppois_R                                                                 ",&
"premult_lower_by_transpose                                              ",&
"pt_R                                                                    ",&
"punif_R                                                                 ",&
"put_ctrl_into_workspace                                                 ",&
"put_data_into_workspace                                                 ",&
"put_method_into_workspace                                               ",&
"put_model_into_workspace                                                ",&
"put_model_type_into_workspace                                           ",&
"put_params_into_workspace                                               ",&
"put_prior_into_workspace                                                ",&
"put_randgen_state_R                                                     ",&
"qbeta_R                                                                 ",&
"qbinom_R                                                                ",&
"qchisq_R                                                                ",&
"qgamma_R                                                                ",&
"qnbinom_R                                                               ",&
"qnorm_R                                                                 ",&
"qpois_R                                                                 ",&
"qsort_double                                                            ",&
"qsort_integer                                                           ",&
"qsort_strings                                                           ",&
"qt_R                                                                    ",&
"qunif_R                                                                 ",&
"rbeta_R                                                                 ",&
"rbinom_R                                                                ",&
"rchisq_R                                                                ",&
"rgamma_R                                                                ",&
"rnbinom_R                                                               ",&
"rnorm_R                                                                 ",&
"row_house                                                               ",&
"row_house_vec                                                           ",&
"rpois_R                                                                 ",&
"rt_R                                                                    ",&
"run_approx_bayes_log_linear                                             ",&
"run_cvam_estimate_em                                                    ",&
"run_cvam_impute_freq                                                    ",&
"run_cvam_impute_microdata                                               ",&
"run_cvam_lik                                                            ",&
"run_cvam_model                                                          ",&
"run_cvam_predict_em                                                     ",&
"run_da_log_linear                                                       ",&
"run_da_saturated                                                        ",&
"run_em_log_linear                                                       ",&
"run_em_saturated                                                        ",&
"run_estep                                                               ",&
"run_estep_single_row                                                    ",&
"run_estep_single_row_with_derivs                                        ",&
"run_estep_with_derivs                                                   ",&
"run_istep                                                               ",&
"run_istep_microdata                                                     ",&
"run_lcprev_loglik_derivs                                                ",&
"run_mh_step_beta_da                                                     ",&
"run_mlogit                                                              ",&
"run_mlogit_loglik_derivs                                                ",&
"run_mstep_log_linear                                                    ",&
"run_rwm_log_linear                                                      ",&
"run_rwm_step_beta                                                       ",&
"runif_R                                                                 ",&
"start_val_log_linear                                                    ",&
"start_val_saturated                                                     ",&
"str1_alloc                                                              ",&
"str1_dealloc                                                            ",&
"str2_alloc                                                              ",&
"str2_dealloc                                                            ",&
"str3_alloc                                                              ",&
"str3_dealloc                                                            ",&
"str_zero_check_single_row                                               ",&
"structural_zero_check                                                   ",&
"sweep_forward                                                           ",&
"sweep_reverse                                                           ",&
"tabulate_integer_number                                                 ",&
"tabulate_integer_variable                                               ",&
"tabulate_real_number                                                    ",&
"tabulate_real_variable                                                  ",&
"tabulate_string                                                         ",&
"tabulate_string_variable                                                ",&
"trigamma_R                                                              ",&
"update_freq_mean                                                        ",&
"update_running_means                                                    ",&
"write_integer_tree_to_table                                             ",&
"write_real_tree_to_table                                                ",&
"write_string_tree_to_table                                              ",&
